@@ -84,7 +84,7 @@ struct _GeditTabPrivate
 	gint                    ask_if_externally_modified : 1;
 };
 
-G_DEFINE_TYPE(GeditTab, gedit_tab, GTK_TYPE_VBOX)
+G_DEFINE_TYPE(GeditTab, gedit_tab, GTK_TYPE_BOX)
 
 enum
 {
@@ -545,11 +545,10 @@ set_info_bar (GeditTab  *tab,
 static void
 remove_tab (GeditTab *tab)
 {
-	GeditNotebook *notebook;
+	GtkWidget *notebook;
 
-	notebook = GEDIT_NOTEBOOK (gtk_widget_get_parent (GTK_WIDGET (tab)));
-
-	gedit_notebook_remove_tab (notebook, tab);
+	notebook = gtk_widget_get_parent (GTK_WIDGET (tab));
+	gtk_container_remove (GTK_CONTAINER (notebook), GTK_WIDGET (tab));
 }
 
 static void 
@@ -951,6 +950,14 @@ remove_tab_idle (GeditTab *tab)
 	return FALSE;
 }
 
+static gboolean
+scroll_to_cursor (GeditTab *tab)
+{
+	gedit_view_scroll_to_cursor (gedit_view_frame_get_view (tab->priv->frame));
+
+	return FALSE;
+}
+
 static void
 document_loaded (GeditDocument *document,
 		 const GError  *error,
@@ -1079,8 +1086,10 @@ document_loaded (GeditDocument *document,
 			gtk_widget_show (emsg);
 		}
 
-		/* Scroll to the cursor when the document is loaded */
-		gedit_view_scroll_to_cursor (gedit_view_frame_get_view (tab->priv->frame));
+		/* Scroll to the cursor when the document is loaded, we need
+		   to do it in an idle as after the document is loaded the
+		   textview is still redrawing and relocating its internals */
+		g_idle_add ((GSourceFunc)scroll_to_cursor, tab);
 
 		/* if the document is readonly we don't care how many times the document
 		   is opened */
@@ -1644,6 +1653,9 @@ gedit_tab_init (GeditTab *tab)
 
 	tab->priv->ask_if_externally_modified = TRUE;
 
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (tab),
+	                                GTK_ORIENTATION_VERTICAL);
+
 	/* Manage auto save data */
 	auto_save = g_settings_get_boolean (tab->priv->editor,
 					    GEDIT_SETTINGS_AUTO_SAVE);
