@@ -422,21 +422,21 @@ get_time (const gchar* format)
 }
 
 static void
-configure_widget_destroyed (GtkObject *obj,
+configure_widget_destroyed (GtkWidget *widget,
 			    gpointer   data)
 {
-	TimeConfigureWidget *widget = (TimeConfigureWidget *)data;
+	TimeConfigureWidget *conf_widget = (TimeConfigureWidget *)data;
 
 	gedit_debug (DEBUG_PLUGINS);
 
-	g_object_unref (widget->settings);
+	g_object_unref (conf_widget->settings);
 	g_slice_free (TimeConfigureWidget, data);
 
 	gedit_debug_message (DEBUG_PLUGINS, "END");
 }
 
 static void
-choose_format_dialog_destroyed (GtkObject *obj,
+choose_format_dialog_destroyed (GtkWidget *widget,
 				gpointer   dialog_pointer)
 {
 	gedit_debug (DEBUG_PLUGINS);
@@ -909,7 +909,6 @@ get_choose_format_dialog (GtkWindow                 *parent,
 			gtk_window_group_add_window (wg, GTK_WINDOW (err_dialog));
 
 		gtk_window_set_resizable (GTK_WINDOW (err_dialog), FALSE);
-		gtk_dialog_set_has_separator (GTK_DIALOG (err_dialog), FALSE);
 		gtk_dialog_set_default_response (GTK_DIALOG (err_dialog), GTK_RESPONSE_OK);
 
 		gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (err_dialog))),
